@@ -4,6 +4,7 @@ import platform
 import random
 import re
 import shutil
+import sys
 import uuid
 from datetime import datetime
 from pathlib import Path
@@ -36,10 +37,8 @@ class SmartLab:
     def __init__(
         self,
         remote: str = 'origin',
-        git_root_dir: Optional[Path] = None,
     ) -> None:
         self._remote = remote
-        self._git_root_dir = git_root_dir
 
         with RESOURCE_DIR.joinpath('dictionary.json').open() as file:
             self._dictionary = json.load(file)
@@ -119,7 +118,6 @@ class SmartLab:
             if target.is_mount():
                 raise RuntimeError(f"Target {target_path} is not versioned by DVC.")
 
-        GITRepo.init(self._git_root_dir or root_dir)
         DVCRepo(root_dir).pull(
             targets=str(target),
             remote=remote or self._remote,
@@ -153,7 +151,6 @@ class SmartLab:
         """
         root_dir = DVCRepo.find_root(root=target)
 
-        GITRepo.init(self._git_root_dir or root_dir)
         DVCRepo(root_dir).add(
             targets=str(target),
             recursive=recursive,
@@ -177,9 +174,11 @@ class SmartLab:
 
         path.with_suffix(path.suffix + '.dvc').unlink(missing_ok=True)
 
-    def metadata(self) -> Dict[str, Any]:
+    @staticmethod
+    def metadata() -> Dict[str, Any]:
         date = datetime.now()
-        repo = GITRepo.init(self._git_root_dir)
+        path, *args = sys.argv
+        repo = GITRepo(path, search_parent_directories=True)
         return dict(
             date=date.strftime('%Y-%m-%d'),
             time=date.strftime('%H:%M:%S'),
@@ -187,6 +186,8 @@ class SmartLab:
             host=platform.node(),
             os=platform.platform(),
             python=platform.python_version(),
+            script=path,
+            args=args,
             git={remote.name: remote.url for remote in repo.remotes},
             branch=repo.active_branch.name,
             commit=repo.active_branch.commit.hexsha if repo.active_branch.is_valid() else None,
